import json
import os
import https.server
import socketserver
import socket
class SendVar:
  def __init__(self,directory,filename='vars.json')
    self.dir = directory
    self.filename = filename

  def host(port):
    handler = https.server.SimpleHTTPRequestHandler
    os.chdir('json')
    with socketserver.TCPServer(('',port), handler) as https: #serve on port
      https.serve_forever()

  def send(self,id,value):
    with open(f'{directory}/{filename}','w') as f:
      f.write(json.dumps({id:value}))


import requests
import json

class GetVar:
  def __init__(self,url):
    self.url = url
  
  def get(self,var):
    req = requests.get(self.url)
    text = req.text
    try:
      return json.loads(text)[var]
    except json.decoder.JSONDecodeError:
      return 'JSONDecodeError'


from distutils.core import setup
setup(
  name = 'onlinevar',
  author_email = 'example@example.com',
  version = '0.0.2',
  classifiers = [
      "Programming Language :: Python :: 3",
  ],
  description = 'online vars in python',
  licence = 'MIT',
  instal_requires =['requests','json','os','https.server','socketserver','socket'],
  packages = ['onlinevar'],
  author = 'ninjamar',
  python_require = '>=3.7',
  url = 'https://github.com/ninjamar/onlinevar'
)